## Library to convert between different Geometry formats

```bash
optional arguments:
  -h, --help            show this help message and exit
  --conversion_type CONVERSION_TYPE, -ct CONVERSION_TYPE
                        Type of conversion to be performed. Options: wkb2wkt, wkb2geojson, wkt2wkb, wkt2geojson, geojson2wkb, geojson2wkt.Default: wkb2wkt
  --input_type INPUT_TYPE, -it INPUT_TYPE
                        Type of input. Options: file or text. Default: text
  --wkb WKB, -wkb WKB   wkb value or path to the file
  --wkt WKT, -wkt WKT   wkt value or path to the file
  --geo_json GEO_JSON, -gj GEO_JSON
                        geojson value or path to the file
